@@ -6,7 +6,7 @@ subst - Greple module for text search and substitution
 
 =head1 VERSION
 
-Version 2.34
+Version 2.35
 
 =head1 SYNOPSIS
 
@@ -15,6 +15,7 @@ greple -Msubst --dict I<dictionary> [ options ]
   Dictionary:
     --dict      dictionary file
     --dictdata  dictionary data
+    --dictpair  dictionary entry pair
 
   Check:
     --check=[ng,ok,any,outstand,all,none]
@@ -71,14 +72,23 @@ C<//> is ignored as a comment in that case.
 
     greple -f DICT ...
 
-Option B<--dictdata> can be used to provide dictionary data in command
-line.
+Option B<--dictdata> can be used to provide dictionary data in the
+command line.
 
-    greple --dictdata $'colou?r color\ncent(er|re) center\n'
+    greple -Msubst \
+           --dictdata $'colou?r color\ncent(er|re) center\n'
 
 Dictionary entry starting with a sharp sign (C<#>) is a comment and
 ignored.
 
+Option B<--dictpair> can be used to provide raw dictionary entries in
+the command line.  In this case, no processing is done regarding
+whitespace or comments.
+
+    greple -Msubst \
+           --dictpair 'colou?r' color \
+           --dictpair 'cent(er|re)' center
+
 =head2 Overlapped pattern
 
 When the matched string is same or shorter than previously matched
@@ -112,6 +122,11 @@ Specify dictionary file.
 
 Specify dictionary data by text.
 
+=item B<--dictpair> I<pattern> I<replacement>
+
+Specify dictionary entry pair.  This option takes two parameters.  The
+first is a pattern and the second is a substitution string.
+
 =item B<--check>=C<outstand>|C<ng>|C<ok>|C<any>|C<all>|C<none>
 
 Option B<--check> takes argument from C<ng>, C<ok>, C<any>,
@@ -378,7 +393,7 @@ it under the same terms as Perl itself.
 use v5.14;
 package App::Greple::subst;
 
-our $VERSION = '2.34';
+our $VERSION = '2.35';
 
 use warnings;
 use utf8;
@@ -400,6 +415,7 @@ use Carp;
 use Data::Dumper;
 use Text::ParseWords qw(shellwords);
 use Encode;
+use List::Util qw(max sum mesh);
 use Getopt::EX::Colormap qw(colorize);
 use Getopt::EX::LabeledParam;
 use App::Greple::Common;
@@ -465,6 +481,13 @@ sub subst_initialize {
     my $config = { linefold  => $opt_linefold,
 		   dictname  => $opt_dictname,
 		   printdict => $opt_printdict };
+    if (@opt_subst_from) {
+	die if @opt_subst_from != @opt_subst_to;
+	push @dicts, App::Greple::subst::Dict->new(
+	    DATA => [ mesh \@opt_subst_from, \@opt_subst_to ],
+	    CONFIG => $config,
+	    );
+    }
     for my $data (@opt_dictdata) {
 	push @dicts, App::Greple::subst::Dict->new(
 	    DATA => $data,
@@ -496,7 +519,6 @@ sub subst_begin {
 
 use Text::VisualWidth::PP;
 use Text::VisualPrintf qw(vprintf vsprintf);
-use List::Util qw(max any sum first);
 
 sub vwidth {
     if (not defined $_[0] or length $_[0] == 0) {
@@ -691,6 +713,8 @@ __DATA__
 
 builtin         dict=s @opt_dictfile
 builtin     dictdata=s @opt_dictdata
+builtin   subst-from=s @opt_subst_from
+builtin     subst-to=s @opt_subst_to
 builtin   stat-style=s $opt_stat_style
 builtin    stat-item=s @opt_stat_item
 builtin    printdict!  $opt_printdict
@@ -715,6 +739,9 @@ option default \
 	--begin subst_begin \
 	--le +&subst_search --no-regioncolor
 
+option --dictpair \
+	--subst-from $<shift> --subst-to $<shift>
+
 ##
 ## Now these options are implemented by -Mupdate module
 ## --diffcmd, -U are built-in options
